package com.caimei365.user.controller;

import com.caimei365.user.idempotent.IpSave;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.BaikeProductDto;
import com.caimei365.user.model.dto.ShopArticleDto;
import com.caimei365.user.model.dto.ShopBannerDto;
import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.BaikeProductPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.ShopService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/9
 */
@Api(tags = "供应商用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/shop")
public class ShopApi {

    private final ShopService shopService;

    @ApiOperation("供应商快捷登录")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/shortcutLogin")
    public ResponseJson<UserLoginVo> shortcutLogin(Integer userId) {
        if (null == userId) {
            return ResponseJson.error(-1, "用户Id不能为空", null);
        }
        return shopService.shortcutLogin(userId);
    }
    /**
     * 根据用户Id查询供应商资料
     * <p>
     * spi旧接口：/supplier/shopInfo
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @ApiOperation("查询供应商资料")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/info")
    public ResponseJson<Map<String, Object>> getShopUserInfo(Integer userId) {
        return shopService.getShopUserInfo(userId);
    }

    /**
     * 修改供应商资料
     * <p>
     * spi旧接口：/supplier/modifiedData
     *
     * @param shopUpdateDto ShopUpdateDto{
     *                      shopId                    供应商Id
     *                      userId                    用户Id
     *                      name                      组织名称
     *                      shortName                 供应商公司简称(shortName)
     *                      email                     邮箱
     *                      contractPhone             固定电话
     *                      linkMan                   联系人
     *                      provinceId                省(provinceID)
     *                      cityId                    市(cityID)
     *                      townId                    所在县区Id(townID)
     *                      address                   地址
     *                      socialCreditCode          统一社会信用代码(营业执照编号)
     *                      businessLicense           营业执照(businessLicenseImage)
     *                      firstShopType             医疗=1和非医疗=2
     *                      secondShopType            医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     *                      mainProduct               主打项目(mainpro)
     *                      mainProductDesc           主打商品说明(productDesc)
     *                      legalPerson               法人代表
     *                      registeredCapital         注册资本
     *                      faxNumber                 传真号(fax)
     *                      companyNature             传真号(nature)
     *                      turnover                  年营业额
     *                      medicalPracticeLicense    医疗执业许可证(medicalPracticeLicenseImg1)
     *                      shopDesc                  公司介绍(info)
     *                      businessScope             经营范围
     *                      logo                      公司LOGO
     *                      operationLicence          生产经营证书(productionLicence)
     *                      hygienicLicense           卫生许可证
     *                      taxLicense                税务登记证
     *                      honorCertification        荣誉证书(certificateHonor)
     *                      productCertification      产品证书
     *                      }
     * @return ClubUpdateDto
     */
    @ApiOperation("更新供应商资料")
    @PostMapping("/info/update")
    public ResponseJson<Void> updateShopUserInfo(ShopUpdateDto shopUpdateDto) {
        String operationLicence = shopUpdateDto.getOperationLicence();
        String hygienicLicense = shopUpdateDto.getHygienicLicense();
        String taxLicense = shopUpdateDto.getTaxLicense();
        String honorCertification = shopUpdateDto.getHonorCertification();
        String productCertification = shopUpdateDto.getProductCertification();
        return shopService.updateShopUserInfo(shopUpdateDto, operationLicence, hygienicLicense, taxLicense, honorCertification, productCertification);
    }

    /**
     * 供应商首页数据
     * @param shopId 供应商Id
     */
    @ApiOperation("供应商首页数据(旧：/supplier/home/detail(supplierId))")
    @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id")
    @GetMapping("/home/data")
    @IpSave(saveName = "供应商首页数据",saveParams = true)
    public ResponseJson<ShopHomeVo> getShopHomeData(Integer shopId) {
        if (null == shopId) {
            return ResponseJson.error("参数异常：供应商Id不能为空！", null);
        }
        return shopService.getShopHomeData(shopId);
    }

    /**
     * 供应商首页-轮播图片
     * @param shopId 供应商Id
     */
    @ApiOperation("供应商首页-轮播图片(旧：/supplier/home/images(supplierId))")
    @GetMapping("/home/images")
    public ResponseJson<List<ShopBannerVo>> getShopHomeImages(Integer shopId) {
        if (null == shopId) {
            return ResponseJson.error("参数异常：供应商Id不能为空！", null);
        }
        return shopService.getShopHomeImages(shopId);
    }

    /**
     * 供应商-更新轮播图片
     * @param shopBannerDto {
     *                      id      图片id
     *                      shopId  供应商Id
     *                      image   图片
     *                      title   名称
     *                      link    链接
     *                      info    描述
     * }
     */
    @ApiOperation("供应商-更新轮播图片(旧：/supplier/saveShopBanner)")
    @PostMapping("/home/images/update")
    public ResponseJson<Void> saveShopHomeImages(ShopBannerDto shopBannerDto) {
        return shopService.saveShopHomeImages(shopBannerDto);
    }

    /**
     * 供应商-删除轮播图片
     * @param shopBannerDto { id  图片id}
     */
    @ApiOperation("供应商-删除轮播图片(旧：/supplier/deleteShopBanner)")
    @PostMapping("/home/images/delete")
    public ResponseJson<Void> deleteShopHomeImages(ShopBannerDto shopBannerDto) {
        if (null == shopBannerDto.getId()) {
            return ResponseJson.error("参数异常：图片Id不能为空！", null);
        }
        return shopService.deleteShopHomeImages(shopBannerDto.getId());
    }

    /**
     * 供应商个人中心数据
     * @param userId 用户Id
     */
    @ApiOperation("供应商个人中心数据(旧：/supplier/homePageData)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "productOrganize", value = "商品上架平台")
    })
    @GetMapping("/personal/data")
    public ResponseJson<Map<String, Object>> getShopPersonalData(Integer userId, Integer productOrganize) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return shopService.getShopPersonalData(userId, productOrganize);
    }

    @ApiOperation("供应商文章表单")
    @ApiImplicitParam(required = true, name = "articleId",value = "文章id")
    @GetMapping("/article/form")
    public ResponseJson<Map<String,Object>> shopArticleForm(Integer articleId) {
        return shopService.getShopArticleById(articleId);
    }

    @ApiOperation("供应商文章保存")
    @PostMapping("/article/save")
    public ResponseJson<Void> saveShopArticle(ShopArticleDto shopArticleDto) {
        return shopService.saveShopArticle(shopArticleDto);
    }

    @ApiOperation("供应商文章列表")
    @GetMapping("/article/list")
    public ResponseJson<PageInfo<ShopArticleVo>> getShopArticleList(ShopArticleDto shopArticleDto,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return shopService.getShopArticleList(shopArticleDto, pageNum, pageSize);
    }

    @ApiOperation("更新供应商文章状态")
    @PostMapping("/article/status/update")
    public ResponseJson<Void> updateArticleStatus(ShopArticleDto shopArticleDto) {
        return shopService.updateArticleStatus(shopArticleDto);
    }

    @ApiOperation("文章分类列表")
    @GetMapping("/article/type/list")
    public ResponseJson<List<ArticleTypeVo>> getArticleTypeList(){
        return shopService.getArticleTypeList();
    }

    @ApiOperation("删除文章")
    @PostMapping("/article/delete")
    public ResponseJson<Void> deleteArticle(Integer articleId){
        return shopService.deleteArticle(articleId);
    }

    @ApiOperation("供应商百科商品表单")
    @ApiImplicitParam(required = true, name = "productId",value = "百科商品id")
    @GetMapping("/baike/product/form")
    public ResponseJson<BaikeProductFormVo> baikeProductForm(Integer productId) {
        return shopService.getBaikeProductById(productId);
    }

    @ApiOperation("供应商百科商品保存")
    @PostMapping("/baike/product/save")
    public ResponseJson<Void> saveBaikeProduct(BaikeProductDto baikeProductDto) {
        return shopService.saveBaikeProduct(baikeProductDto);
    }

    @ApiOperation("供应商百科商品列表")
    @GetMapping("/baike/product/list")
    public ResponseJson<PageInfo<BaikeProductListVo>> getBaikeProductList(BaikeProductDto baikeProductDto,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return shopService.getBaikeProductList(baikeProductDto, pageNum, pageSize);
    }

    @ApiOperation("更新供应商百科商品状态")
    @PostMapping("/baike/product/status/update")
    public ResponseJson<Void> updateBaikeProductStatus(BaikeProductDto baikeProductDto) {
        return shopService.updateBaikeProductStatus(baikeProductDto);
    }

    @ApiOperation("百科商品分类列表")
    @ApiImplicitParam(required = true, name = "commodityType",value = "百科分类：1产品，2仪器")
    @GetMapping("/baike/product/type/list")
    public ResponseJson<List<BaikeProductTypeVo>> getBaikeProductTypeList(Integer commodityType){
        return shopService.getBaikeProductTypeList(commodityType);
    }

    @ApiOperation("删除百科商品")
    @ApiImplicitParam(required = true, name = "productId",value = "百科商品id")
    @PostMapping("/baike/product/delete")
    public ResponseJson<Void> deleteBaikeProduct(Integer productId){
        return shopService.deleteBaikeProduct(productId);
    }

    @ApiOperation("查询敏感词")
    @ApiImplicitParam(required = true, name = "checkPoint", value = "检查位置：1供应商端文章，2供应商端百科，3管理员端文章，4管理员端百科")
    @GetMapping("/sensitive/words")
    public ResponseJson<String> getSensitiveWords(Integer checkPoint){
        if (null == checkPoint) {
            return ResponseJson.error("参数异常", null);
        }
        return shopService.getSensitiveWords(checkPoint);
    }

    @ApiOperation("百科相关推荐表单")
    @ApiImplicitParam(required = true, name = "productId", value = "百科产品id")
    @GetMapping("/baike/recommend/form")
    public ResponseJson<Map<String,Object>> baikeRecommendForm(Integer productId){
        return shopService.getBaikeRecommendForm(productId);
    }

    @ApiOperation("百科相关推荐添加产品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "productId", value = "百科产品id"),
            @ApiImplicitParam(required = false, name = "typeId", value = "分类id"),
            @ApiImplicitParam(required = false, name = "name", value = "名称"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/baike/recommend/add/list")
    public ResponseJson<PageInfo<BaikeProductListVo>> addRecommendList(Integer productId, Integer typeId, String name,
                                                                     @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                     @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == productId) {
            return ResponseJson.error("百科产品id不能为空", null);
        }
        if (null == typeId) {
            return ResponseJson.error("分类id不能为空", null);
        }
        return shopService.getAddRecommendList(productId, typeId, name, pageNum, pageSize);
    }

    @ApiOperation("百科相关推荐添加产品")
    @PostMapping("/baike/recommend/add")
    public ResponseJson<Void> addBaikeRecommend(BaikeProductDto baikeProduct){
        if (null == baikeProduct.getProductId()) {
            return ResponseJson.error("商品id不能为空", null);
        }
        return shopService.addBaikeRecommend(baikeProduct);
    }

    @ApiOperation("百科相关推荐删除产品")
    @ApiImplicitParam(required = true, name = "recommendId", value = "相关推荐id")
    @PostMapping("/baike/recommend/delete")
    public ResponseJson<Void> deleteBaikeRecommend(Integer recommendId){
        if (null == recommendId) {
            return ResponseJson.error("相关推荐id不能为空", null);
        }
        return shopService.deleBaikeRecommend(recommendId);
    }

    @ApiOperation("百科相关推荐更改排序")
    @PostMapping("/baike/recommend/sort/save")
    public ResponseJson<Void> saveRecommendSort(BaikeRecommendVo baikeRecommend){
        if (null == baikeRecommend.getRecommendId()) {
            return ResponseJson.error("相关推荐id不能为空", null);
        }
        if (null == baikeRecommend.getSort()) {
            return ResponseJson.error("排序值不能为空", null);
        }
        return shopService.saveRecommendSort(baikeRecommend);
    }

    @ApiOperation("百科相关推荐更改推荐方式")
    @PostMapping("/baike/recommend/type/save")
    public ResponseJson<Void> saveRecommendType(BaikeProductDto baikeProduct){
        if (null == baikeProduct.getProductId()) {
            return ResponseJson.error("商品id不能为空", null);
        }
        if (null == baikeProduct.getRecommendType()) {
            return ResponseJson.error("推荐类型不能为空", null);
        }
        return shopService.saveRecommendType(baikeProduct);
    }
}
